summaryrefslogtreecommitdiff
path: root/src/core/commands.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/core/commands.h')
-rw-r--r--src/core/commands.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/core/commands.h b/src/core/commands.h
index bdc8755d..b4f4ea0e 100644
--- a/src/core/commands.h
+++ b/src/core/commands.h
@@ -38,7 +38,8 @@ enum {
CMDERR_CHAN_NOT_SYNCED, /* channel not fully synchronized yet */
CMDERR_ILLEGAL_PROTO, /* requires different chat protocol than the active server */
CMDERR_NOT_GOOD_IDEA, /* not good idea to do, -yes overrides this */
- CMDERR_INVALID_TIME /* invalid time specification */
+ CMDERR_INVALID_TIME, /* invalid time specification */
+ CMDERR_INVALID_CHARSET /* invalid charset specification */
};
/* Return the full command for `alias' */